#!/bin/bash

# Preprocessing step for VATool (see README --> Prerequisites)
# computes optical flow, point trajectories and pairwise affinites

# Report bugs to nagaraja@cs.uni-freiburg.de

if [ $# -ne 1 ]; then
        echo "script expects one argument - absolute path to bmf file";
        echo " e.g. ./computeTracks.sh /tmp/bear01/bear01.bmf";
        exit;
fi

bmfFile=${1};
parentDir=${bmfFile%/*};
dataDir=${parentDir%/*};
video=${parentDir##*/};
nframes=$(head -1 ${bmfFile} | cut -d" " -f1);
# trajectory spacing, change it if you want sparser trajectories.
spacing=8;

# create trackfiles sub-directory, to be used with GUI later
tracksDir=${parentDir}/trackfiles;
mkdir -p ${tracksDir};
echo "Trajectory related files in ${tracksDir}";

cp dummy.cfg test.cfg;
instr=FOLDER;
outstr=OUTDIR;
sed -i s@${instr}@${dataDir}@g test.cfg;
sed -i s@${outstr}@${parentDir}@g test.cfg;

# run Motion Segmentation from Ochs et al. (see README --> Citation)
echo "Running Motion Segmentation from Ochs et al. (see README --> Citation)";
./MotionSegmentation test.cfg ${video} 0 ${nframes} ${spacing};

# soft linking required files (to be used with GUI)
for f in ${parentDir}/OchsBroxMalik*/${video}/Graph*.dat; do
        filename=${f##*/};
        ln -s ${f} ${tracksDir}/${filename};
done
